summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:55:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:55:40 -0600
commit73ff676f11662d6178c8854a7832ebffe2ae409d (patch)
tree9e89ea7d87940087d2d3c5db9b378ef989dd1346 /kexi/kexidb
parentc2ba2f56121c21a762619faf195e8332ef5b224f (diff)
downloadkoffice-73ff676f11662d6178c8854a7832ebffe2ae409d.tar.gz
koffice-73ff676f11662d6178c8854a7832ebffe2ae409d.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'kexi/kexidb')
-rw-r--r--kexi/kexidb/drivermanager.cpp6
-rw-r--r--kexi/kexidb/simplecommandlineapp.cpp8
-rw-r--r--kexi/kexidb/simplecommandlineapp.h6
3 files changed, 10 insertions, 10 deletions
diff --git a/kexi/kexidb/drivermanager.cpp b/kexi/kexidb/drivermanager.cpp
index 677709e4..b5713297 100644
--- a/kexi/kexidb/drivermanager.cpp
+++ b/kexi/kexidb/drivermanager.cpp
@@ -91,9 +91,9 @@ bool DriverManagerInternal::lookupDrivers()
if (tqApp) {
connect(tqApp,TQT_SIGNAL(aboutToQuit()),this,TQT_SLOT(slotAppQuits()));
}
-//TODO: for QT-only version check for KInstance wrapper
-// KexiDBWarn << "DriverManagerInternal::lookupDrivers(): cannot work without KInstance (KGlobal::instance()==0)!" << endl;
-// setError("Driver Manager cannot work without KInstance (KGlobal::instance()==0)!");
+//TODO: for QT-only version check for TDEInstance wrapper
+// KexiDBWarn << "DriverManagerInternal::lookupDrivers(): cannot work without TDEInstance (KGlobal::instance()==0)!" << endl;
+// setError("Driver Manager cannot work without TDEInstance (KGlobal::instance()==0)!");
lookupDriversNeeded = false;
clearError();
diff --git a/kexi/kexidb/simplecommandlineapp.cpp b/kexi/kexidb/simplecommandlineapp.cpp
index 6ba6624b..5b3732a5 100644
--- a/kexi/kexidb/simplecommandlineapp.cpp
+++ b/kexi/kexidb/simplecommandlineapp.cpp
@@ -72,7 +72,7 @@ public:
KexiDB::DriverManager manager;
KCmdLineOptions *allOptions;
- KInstance* instance;
+ TDEInstance* instance;
ConnectionData connData;
TQGuardedPtr<Connection> conn;
};
@@ -91,7 +91,7 @@ SimpleCommandLineApp::SimpleCommandLineApp(
TQFileInfo fi(argv[0]);
TQCString appName( fi.baseName().latin1() );
TDECmdLineArgs::init(argc, argv,
- new KAboutData( appName, programName,
+ new TDEAboutData( appName, programName,
version, shortDescription, licenseType, copyrightStatement, text,
homePageAddress, bugsEmailAddress));
@@ -102,7 +102,7 @@ SimpleCommandLineApp::SimpleCommandLineApp(
for (KCmdLineOptions *optionsPtr = options; optionsPtr->name; optionsPtr++, userOptionsCount++)
;
- d->instance = new KInstance(appName);
+ d->instance = new TDEInstance(appName);
// join the predefined options and user options
d->allOptions = new KCmdLineOptions[predefinedOptionsCount + userOptionsCount + 1];
@@ -212,7 +212,7 @@ bool SimpleCommandLineApp::closeDatabase()
return true;
}
-KInstance* SimpleCommandLineApp::instance() const
+TDEInstance* SimpleCommandLineApp::instance() const
{
return d->instance;
}
diff --git a/kexi/kexidb/simplecommandlineapp.h b/kexi/kexidb/simplecommandlineapp.h
index c14a35ea..64cc1382 100644
--- a/kexi/kexidb/simplecommandlineapp.h
+++ b/kexi/kexidb/simplecommandlineapp.h
@@ -30,7 +30,7 @@ struct KCmdLineOptions;
namespace KexiDB
{
//! @short A skeleton for creating a simple command line database application.
/*! This class creates a KInstance object and automatically handles the following
command line options:
- --driver \<name\> (Database driver name) or -drv
- --user \<name\> (Database user name) or -u
@@ -49,14 +49,14 @@ namespace KexiDB
SimpleCommandLineApp(
int argc, char** argv, KCmdLineOptions *options, const char *programName,
const char *version, const char *shortDescription=0,
- int licenseType=KAboutData::License_Unknown,
+ int licenseType=TDEAboutData::License_Unknown,
const char *copyrightStatement=0, const char *text=0,
const char *homePageAddress=0, const char *bugsEmailAddress="submit@bugs.kde.org");
~SimpleCommandLineApp();
//! \return program instance
- KInstance* instance() const;
+ TDEInstance* instance() const;
/*! Opens database \a databaseName for connection data
specified via the command line. \return true in success.
@@ -30,7 +30,7 @@ struct KCmdLineOptions;
{
//! @short A skeleton for creating a simple command line database application.
- /*! This class creates a KInstance object and automatically handles the following
+ /*! This class creates a TDEInstance object and automatically handles the following
command line options: